==> nextcloud-15.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/lt_LT.js <==
OC.L10N.register(
    "comments",
    {
    "Edit comment" : "Keisti",
    "Delete comment" : "Ištrinti",
    "New comment …" : "Komentaras",
    "Post" : "Įrašas",
    "Cancel" : "Atsisakyti",
    "[Deleted user]" : "[Ištrintas naudotojas]",
    "Comments" : "Komentarai",
    "No comments yet, start the conversation!" : "Nėra komentarų",
    "More comments …" : "Daugiau",
    "Save" : "Įrašyti",
    "Allowed characters {count} of {max}" : "Leidžiama simbolių {count} iš {max}",
    "Error occurred while updating comment with id {id}" : "Klaida bandant pataisyti komentarą pagal identifikavimo numerį {id}",
    "Error occurred while posting comment" : "Nepavyko įrašyti komentaro",
    "_%n unread comment_::_%n unread comments_" : ["%n neskaitytas komentaras","%n neskaityti komentarai","%n neskaitytų komentarų","%n neskaitytų komentarų"],
    "Comment" : "Komentaras",
    "You commented" : "Jūs pakomentavote",
    "%1$s commented" : "%1$s pakomentavo",
    "{author} commented" : "{author} pakomentavo",
    "You commented on %1$s" : "Pakomentavote %1$s",
    "You commented on {file}" : "Pakomentavote {file}",
    "%1$s commented on %2$s" : "%1$s pakomentavo %2$s",
    "{author} commented on {file}" : "{author} pakomentavo {file}",
    "<strong>Comments</strong> for files" : "<strong>Failų komentarai</strong>",
    "{user} mentioned you in a comment on “{file}”" : "{user} jus paminėjo komentare “{file}”",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s jus paminėjo komentare \"%2$s\""
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-15.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/lt_LT.js <==
OC.L10N.register(
    "comments",
    {
    "Edit comment" : "Taisyti komentarą",
    "Delete comment" : "Ištrinti komentarą",
    "New comment …" : "Naujas komentaras …",
    "Post" : "Įrašas",
    "Cancel" : "Atsisakyti",
    "[Deleted user]" : "[Ištrintas naudotojas]",
    "Comments" : "Komentarai",
    "No comments yet, start the conversation!" : "Nėra komentarų",
    "More comments …" : "Daugiau",
    "Save" : "Įrašyti",
    "Allowed characters {count} of {max}" : "Leidžiama simbolių {count} iš {max}",
    "Error occurred while updating comment with id {id}" : "Klaida bandant pataisyti komentarą pagal identifikavimo numerį {id}",
    "Error occurred while posting comment" : "Skelbiant komentarą, įvyko klaida",
    "_%n unread comment_::_%n unread comments_" : ["%n neskaitytas komentaras","%n neskaityti komentarai","%n neskaitytų komentarų","%n neskaitytų komentarų"],
    "Comment" : "Komentaras",
    "You commented" : "Jūs pakomentavote",
    "%1$s commented" : "%1$s pakomentavo",
    "{author} commented" : "{author} pakomentavo",
    "You commented on %1$s" : "Pakomentavote %1$s",
    "You commented on {file}" : "Pakomentavote {file}",
    "%1$s commented on %2$s" : "%1$s pakomentavo %2$s",
    "{author} commented on {file}" : "{author} pakomentavo {file}",
    "<strong>Comments</strong> for files" : "<strong>Failų komentarai</strong>",
    "{user} mentioned you in a comment on “{file}”" : "{user} jus paminėjo komentare “{file}”",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s jus paminėjo komentare \"%2$s\""
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
